@@ -9,6 +9,7 @@ from preseem.preseem_model import BaseModelObject
 class FakePreseemModel:
     _companies = {} # company_uuid to Company object
     _elements = {}  # company_uuid to {element_uuid to Element object}
+    _packages = {}  # company_uuid to {package_uuid to Package object}
     _sites = {}     # company_uuid to {site_uuid to Site object}
     _elem_disc = {} # company_uuid to {uuid to ElementDiscovery object}
 
@@ -202,6 +203,60 @@ class FakePreseemModel:
                         setattr(disc, attr, val)
 
 
+    class Package(BaseModelObject):
+        @classmethod
+        async def Create(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            assert company_uuid
+            company = FakePreseemModel._companies[company_uuid]
+            obj = cls(**FakePreseemModel._new_attrs(),
+                    company_uuid=company.uuid,
+                    name=kwargs.get('name') or '',
+                    source=kwargs.get('source'),
+                    source_id=kwargs.get('source_id'),
+                    download_rate=kwargs.get('download_rate'),
+                    upload_rate=kwargs.get('upload_rate'))
+            packages = FakePreseemModel._packages.get(company.uuid)
+            if packages is None:
+                packages = FakePreseemModel._packages[company_uuid] = {}
+            packages[obj.uuid] = obj
+            return copy.deepcopy(obj)
+
+        @classmethod
+        async def List(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            assert company_uuid
+            # the real impl returns empty list if the company doesn't exist
+            return [copy.deepcopy(x) for x in (FakePreseemModel._packages.get(company_uuid) or {}).values()]
+
+        @classmethod
+        async def Delete(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            packages = FakePreseemModel._packages[company_uuid]
+            if packages:
+                package = packages.get(uuid)
+                if package:
+                    del packages[uuid]
+
+        @classmethod
+        async def Update(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            packages = FakePreseemModel._packages[company_uuid]
+            if packages:
+                package = packages.get(uuid)
+                for attr, val in kwargs.items():
+                    if attr == 'company_uuid' or attr == 'uuid':
+                        continue
+                    elif attr == 'inactive' and val is True:
+                        FakePreseemModel._set_inactive(package)
+                    else:
+                        if getattr(package, attr) != val:
+                            package.updated_at = time.time()
+                        setattr(package, attr, val)
+
+
     class Site(BaseModelObject):
         @classmethod
         async def Create(cls, **kwargs):
